<?php

/*
 * Discussion Board Pro admin class
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Plugin admin class
 **/

class CT_DB_Pro_Admin {

	/*
	 * Initialize the class and start calling our hooks and filters
	 * @since 1.0.0
	 */
	public function init() {
		add_filter( 'ct_db_settings_tabs', array( $this, 'filter_tabs' ) );
		add_action( 'admin_init', array( $this, 'register_pro_init' ) );
		add_action( 'admin_init', array( $this, 'register_categories_init' ) );
		add_action( 'admin_init', array( $this, 'register_boards_init' ) );
		add_action( 'admin_init', array( $this, 'register_registration_init' ) );
		add_action( 'admin_init', array( $this, 'profiles_registration_init' ) );
		add_action( 'admin_init', array( $this, 'followers_registration_init' ) );
		add_filter( 'admin_body_class', array( $this, 'filter_admin_body_classes' ) );
	}

	public function filter_admin_body_classes( $classes ) {
		$classes .= ' is-dbpro';
		return $classes;
	}

	public function register_pro_init() {
		register_setting( 'ctdb_pro', 'ctdb_pro_settings' );
		add_settings_section(
			'ctdb_pro_section',
			__( 'Pro Settings', 'discussion-board-pro' ),
			array( $this, 'pro_settings_section_callback' ),
			'ctdb_pro'
		);

		$pro_settings = ctdb_pro_settings();
		if( ! empty( $pro_settings ) ) {
			foreach( $pro_settings as $pro_setting ) {
				add_settings_field(
					$pro_setting['id'],
					$pro_setting['label'],
					array ( $this, $pro_setting['callback'] ),
					'ctdb_pro',
					'ctdb_pro_section',
					$pro_setting
				);
			}
		}

		// Set default options
		$options = get_option( 'ctdb_pro_settings' );
		if( false === $options ) {
			// Get defaults
			$defaults = $this -> get_default_pro_settings();
			update_option( 'ctdb_pro_settings', $defaults );
		}

	}

	public function get_default_pro_settings() {
		$defaults = array(
			'include_image_upload'		=> 0,
			'always_allow_comments'		=> 0,
			'use_editor'				=> 0,
			'time_format'				=> 'standard',
			'freshness_time_format'		=> 'freshness',
			'enable_status'				=> 'global',
			'default_statuses'			=> __( 'Open, Fixed', 'discussion-board-pro' ),
			'poster_set_status'			=> 0
		);
		return $defaults;
	}

	public function register_categories_init() {
		register_setting( 'ctdb_categories', 'ctdb_categories_settings' );
		add_settings_section(
			'ctdb_categories_section',
			__( 'Categories Settings', 'discussion-board-pro' ),
			array( $this, 'categories_settings_section_callback' ),
			'ctdb_categories'
		);

		add_settings_field(
			'allow_categories',
			__( 'Allow categories', 'discussion-board-pro' ),
			array( $this, 'allow_categories_render' ),
			'ctdb_categories',
			'ctdb_categories_section'
		);

		add_settings_field(
			'create_categories',
			__( 'Create categories', 'discussion-board-pro' ),
			array( $this, 'create_categories_render' ),
			'ctdb_categories',
			'ctdb_categories_section'
		);

		add_settings_field(
			'allow_tags',
			__( 'Allow tags', 'discussion-board-pro' ),
			array( $this, 'allow_tags_render' ),
			'ctdb_categories',
			'ctdb_categories_section'
		);

		add_settings_field(
			'categories_position',
			__( 'Display categories', 'discussion-board-pro' ),
			array( $this, 'categories_position_render' ),
			'ctdb_categories',
			'ctdb_categories_section'
		);

		// Set default options
		$options = get_option( 'ctdb_categories_settings' );
		if( false === $options ) {
			// Get defaults
			$defaults = $this -> get_default_categories_settings();
			update_option( 'ctdb_categories_settings', $defaults );
		}

	}

	public function get_default_categories_settings() {
		$defaults = array(
			'allow_categories'		=> 0,
			'create_categories'		=> 0,
			'allow_tags'			=> 0,
			'categories_position'	=> 'above-content'
		);
		return $defaults;
	}

	// Boards Settings
	public function register_boards_init() {
		register_setting( 'ctdb_boards', 'ctdb_boards_settings' );
		add_settings_section(
			'ctdb_boards_section',
			__( 'Boards Settings', 'discussion-board-pro' ),
			array( $this, 'boards_settings_section_callback' ),
			'ctdb_boards'
		);

		add_settings_field(
			'enable_boards',
			__( 'Enable Boards', 'discussion-board-pro' ),
			array( $this, 'enable_boards_render' ),
			'ctdb_boards',
			'ctdb_boards_section'
		);

		add_settings_field(
			'boards_override_template',
			__( 'Override theme template', 'discussion-board-pro' ),
			array( $this, 'boards_override_template_render' ),
			'ctdb_boards',
			'ctdb_boards_section'
		);
		/*
		add_settings_field(
			'boards_breadcrumb',
			__( 'Enable breadcrumb', 'discussion-board-pro' ),
			array( $this, 'boards_breadcrumb_render' ),
			'ctdb_boards',
			'ctdb_boards_section'
		); */

		add_settings_field(
			'boards_meta_fields',
			__( 'Boards meta fields (summary)', 'discussion-board-pro' ),
			array( $this, 'boards_meta_fields_render' ),
			'ctdb_boards',
			'ctdb_boards_section'
		);

		add_settings_field(
			'boards_meta_fields_archive',
			__( 'Boards meta fields (archive)', 'discussion-board-pro' ),
			array( $this, 'boards_meta_fields_archive_render' ),
			'ctdb_boards',
			'ctdb_boards_section'
		);

		add_settings_field(
			'boards_orderby',
			__( 'Boards orderby', 'discussion-board-pro' ),
			array( $this, 'boards_orderby_render' ),
			'ctdb_boards',
			'ctdb_boards_section'
		);

		add_settings_field(
			'boards_order',
			__( 'Boards order', 'discussion-board-pro' ),
			array( $this, 'boards_order_render' ),
			'ctdb_boards',
			'ctdb_boards_section'
		);

		add_settings_field(
			'topics_in_boards',
			__( 'Topics', 'discussion-board-pro' ),
			array( $this, 'topics_in_boards_render' ),
			'ctdb_boards',
			'ctdb_boards_section'
		);

		add_settings_field(
			'new_topic_button_archive',
			__( 'Show New Topic button on archive', 'discussion-board-pro' ),
			array( $this, 'new_topic_button_archive_render' ),
			'ctdb_boards',
			'ctdb_boards_section'
		);


		// Set default options
		$options = get_option( 'ctdb_boards_settings' );
		if( false === $options ) {
			// Get defaults
			$defaults = $this->get_default_boards_settings();
			update_option( 'ctdb_boards_settings', $defaults );
		}

	}

	public function get_default_boards_settings() {
		$defaults = array(
			'enable_boards'					=> 0,
			'boards_override_template'		=> 0,
			'boards_breadcrumb'				=> 0,
			'boards_fields'					=> array( 'topics', 'replies', 'freshness', 'voices' ),
			'boards_meta_fields_archive'	=> array( 'topics', 'replies', 'freshness', 'voices' ),
			'boards_orderby'				=> 'freshness',
			'boards_order'					=> 'DESC',
			'topics_in_boards'				=> 5,
			'new_topic_button_archive'		=> 'top'
		);
		return $defaults;
	}


	public function register_registration_init() {
		register_setting( 'ctdb_registration', 'ctdb_registration_settings' );
		add_settings_section(
			'ctdb_registration_section',
			__( 'Registration Settings', 'discussion-board-pro' ),
			array( $this, 'registration_settings_section_callback' ),
			'ctdb_registration'
		);

		add_settings_field(
			'register_firstname',
			__( 'First Name', 'discussion-board-pro' ),
			array( $this, 'register_firstname_render' ),
			'ctdb_registration',
			'ctdb_registration_section'
		);

		add_settings_field(
			'register_lastname',
			__( 'Last Name', 'discussion-board-pro' ),
			array( $this, 'register_lastname_render' ),
			'ctdb_registration',
			'ctdb_registration_section'
		);

		add_settings_field(
			'register_url',
			__( 'Website', 'discussion-board-pro' ),
			array( $this, 'register_url_render' ),
			'ctdb_registration',
			'ctdb_registration_section'
		);

		add_settings_field(
			'register_bio',
			__( 'Bio', 'discussion-board-pro' ),
			array( $this, 'register_bio_render' ),
			'ctdb_registration',
			'ctdb_registration_section'
		);


		// Set default options
		$options = get_option( 'ctdb_registration_settings' );
		if( false === $options ) {
			// Get defaults
			$defaults = $this -> get_default_registration_settings();
			update_option( 'ctdb_registration_settings', $defaults );
		}

	}

	public function get_default_registration_settings() {
		$defaults = array(
			'register_url'			=> 'hide',
			'register_firstname'	=> 'required',
			'register_lastname'		=> 'required',
			'register_bio'			=> 'hide'
		);
		return $defaults;
	}


	public function profiles_registration_init() {
		register_setting( 'ctdb_profiles', 'ctdb_profiles_settings' );
		add_settings_section(
			'ctdb_profiles_section',
			__( 'Profiles Settings', 'discussion-board-pro' ),
			array( $this, 'profiles_settings_section_callback' ),
			'ctdb_profiles'
		);

		add_settings_field(
			'enable_profiles',
			__( 'Enable profiles', 'discussion-board-pro' ),
			array( $this, 'enable_profiles_render' ),
			'ctdb_profiles',
			'ctdb_profiles_section'
		);

		add_settings_field(
			'profiles_tabs',
			__( 'Profiles tabs', 'discussion-board-pro' ),
			array( $this, 'profiles_tabs_render' ),
			'ctdb_profiles',
			'ctdb_profiles_section'
		);

		add_settings_field(
			'profiles_fields',
			__( 'Profiles fields', 'discussion-board-pro' ),
			array( $this, 'profiles_fields_render' ),
			'ctdb_profiles',
			'ctdb_profiles_section'
		);

		add_settings_field(
			'redirect_to_profile_page',
			__( 'Profile URL', 'discussion-board-pro' ),
			array( $this, 'redirect_to_profile_page_render' ),
			'ctdb_profiles',
			'ctdb_profiles_section'
		);

		/*
		add_settings_field(
			'enable_author_sidebar',
			__( 'Enable sidebar on Author page', 'discussion-board-pro' ),
			array( $this, 'enable_author_sidebar_render' ),
			'ctdb_profiles',
			'ctdb_profiles_section'
		); */

		// Set default options
		$options = get_option( 'ctdb_profiles_settings' );
		if( false === $options ) {
			// Get defaults
			$defaults = $this -> get_default_profiles_settings();
			update_option( 'ctdb_profiles_settings', $defaults );
		}

	}

	public function get_default_profiles_settings() {
		$defaults = array(
			'enable_profiles'		=> 0,
			'enable_author_sidebar'	=> 0,
			'profiles_tabs'			=> ''
		);
		return $defaults;
	}

	public function followers_registration_init() {

		register_setting( 'ctdb_followers', 'ctdb_followers_settings' );

		add_settings_section(
			'ctdb_followers_section',
			__( 'Followers Settings', 'discussion-board-pro' ),
			array( $this, 'followers_settings_section_callback' ),
			'ctdb_followers'
		);

		$followers_settings = ctdb_followers_settings();
		if( ! empty( $followers_settings ) ) {
			foreach( $followers_settings as $followers_setting ) {
				add_settings_field(
					$followers_setting['id'],
					$followers_setting['label'],
					array ( $this, $followers_setting['callback'] ),
					'ctdb_followers',
					'ctdb_followers_section',
					$followers_setting
				);
			}
		}

		// Set default options
		$options = get_option( 'ctdb_followers_settings' );
		if( false === $options ) {
			// Get defaults
			$defaults = $this -> get_default_followers_settings();
			update_option( 'ctdb_followers_settings', $defaults );
		}

	}

	public function get_default_followers_settings() {
		$defaults = array(
			'enable_topic_following'		=> 0,
			'display_follower_numbers'		=> 0,
			'display_all_user_followers'	=> 0,
		);
		return $defaults;
	}

	/**
	 * Callback for header setting.
	 *
	 * @param $args array Callback arguments.
	 */
	public function page_header_callback( $args ) {
		$options = get_option( $args['section'] );
		$value   = '';
		if ( isset( $options[ $args['id'] ] ) ) {
			// Ensure value is prefixed with #
			$value = '#' . str_replace( '#', '', $options[ $args['id'] ] );
		}
	}

	// Callback for pages select field
	public function pages_select_callback( $args ) {
		$options = get_option( $args['section'] );
		$value = '';
		if( isset( $options[$args['id']] ) ) {
			$value = $options[$args['id']];
		}
		// Get all pages
		$pages = get_pages();

		// Iterate through the pages
		if ( $pages ) { ?>
			<select name='<?php echo $args['section']; ?>[<?php echo $args['id']; ?>]'>
				<option></option>
				<?php foreach ( $pages as $page ) { ?>
					<option value='<?php echo $page -> ID; ?>' <?php selected( $value, $page -> ID ); ?>><?php echo $page -> post_title; ?></option>
				<?php } ?>
			</select>
		<?php }
		if( isset( $args['description'] ) ) { ?>
			<p class="description"><?php echo $args['description']; ?></p>
		<?php }
	}

	public function text_callback( $args ) {
		$options = get_option( $args['section'] );
		$value = '';
		if( isset( $options[$args['id']] ) ) {
			$value = $options[$args['id']];
		} ?>
		<input type='text' name="<?php echo $args['section']; ?>[<?php echo $args['id']; ?>]" value='<?php echo esc_attr( $value ); ?>'>
		<?php
		if( isset( $args['description'] ) ) { ?>
			<p class="description"><?php echo $args['description']; ?></p>
		<?php }
	}

	public function wysiwyg_callback( $args ) {
		$options = get_option( $args['section'] );
		$value = '';
		if( isset( $options[$args['id']] ) ) {
			$value = $options[$args['id']];
		}
		$name = $args['section'] . '[' . $args['id'] . ']';
		wp_editor(
			$value,
			$args['id'],
			array(
				'textarea_name' => $name,
				'media_buttons'	=> false,
				'wpautop'		=> false,
				'tinymce'		=> true,
				'quicktags'		=> true,
				'textarea_rows'	=> 5
			)
		);
		if( isset( $args['description'] ) ) { ?>
			<p class="description"><?php echo $args['description']; ?></p>
		<?php }
	}

	public function checkbox_callback( $args ) {
		$options = get_option( $args['section'] );
		$value = '';
		if( isset( $options[$args['id']] ) ) {
			$value = $options[$args['id']];
		} ?>
		<input type='checkbox' name="<?php echo $args['section']; ?>[<?php echo $args['id']; ?>]" <?php checked( ! empty( $value ), 1 ); ?> value='1'>
		<?php
		if( isset( $args['description'] ) ) { ?>
			<p class="description"><?php echo $args['description']; ?></p>
		<?php }
	}

	public function select_callback( $args ) {
		$options = get_option( $args['section'] );
		$current_value = '';
		if( isset( $options[$args['id']] ) ) {
			$current_value = $options[$args['id']];
		}
		// Iterate through the options
		if ( isset( $args['choices'] ) ) { ?>
			<select name='<?php echo $args['section']; ?>[<?php echo $args['id']; ?>]'>
				<?php foreach ( $args['choices'] as $key=>$value ) { ?>
					<option value='<?php echo esc_attr( $key ) ?>' <?php selected( $current_value, $key ); ?>><?php echo esc_attr( $value ); ?></option>
				<?php } ?>
			</select>
		<?php }
		if( isset( $args['description'] ) ) { ?>
			<p class="description"><?php echo $args['description']; ?></p>
		<?php }
	}


	public function allow_categories_render() {
		$options = get_option( 'ctdb_categories_settings' );
		?>
		<input type='checkbox' name='ctdb_categories_settings[allow_categories]' <?php checked( ! empty( $options['allow_categories'] ), 1 ); ?> value='1'>
		<p class="description"><?php _e( 'Enable discussion categories.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function create_categories_render() {
		$options = get_option( 'ctdb_categories_settings' );
		?>
		<input type='checkbox' name='ctdb_categories_settings[create_categories]' <?php checked( ! empty( $options['create_categories'] ), 1 ); ?> value='1'>
		<p class="description"><?php _e( 'Allow the user to create new categories.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function categories_position_render() {
		$options = get_option( 'ctdb_categories_settings' );
		?>
		<select name='ctdb_categories_settings[categories_position]'>
			<option value='hide' <?php selected( $options['categories_position'], 'hide' ); ?>>Hide</option>
			<option value='above-content' <?php selected( $options['categories_position'], 'above-content' ); ?>>Above Content</option>
			<option value='below-content' <?php selected( $options['categories_position'], 'below-content' ); ?>>Below Content</option>
		</select>
		<p class="description"><?php _e( 'Only applies to standard layout.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function allow_tags_render() {
		$options = get_option( 'ctdb_categories_settings' );
		?>
		<input type='checkbox' name='ctdb_categories_settings[allow_tags]' <?php checked( ! empty( $options['allow_tags'] ), 1 ); ?> value='1'>
		<p class="description"><?php _e( 'Enable discussion tags.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	// Boards functions
	public function enable_boards_render() {
		$options = get_option( 'ctdb_boards_settings' );
		?>
		<input type='checkbox' name='ctdb_boards_settings[enable_boards]' <?php checked( ! empty( $options['enable_boards'] ), 1 ); ?> value='1'>
		<p class="description"><?php _e( 'Enable Discussion Boards.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function boards_override_template_render() {
		$options = get_option( 'ctdb_boards_settings' );
		?>
		<input type='checkbox' name='ctdb_boards_settings[boards_override_template]' <?php checked( ! empty( $options['boards_override_template'] ), 1 ); ?> value='1'>
		<p class="description"><?php _e( 'Select this to use the plugin\'s taxonomy-board.php template. Note that this might create a conflict with your theme.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	// Boards functions
	/*
	public function boards_breadcrumb_render() {
		$options = get_option( 'ctdb_boards_settings' );
		?>
		<input type='checkbox' name='ctdb_boards_settings[boards_breadcrumb]' <?php checked( ! empty( $options['boards_breadcrumb'] ), 1 ); ?> value='1'>
		<p class="description"><?php _e( 'Add a breadcrumb navigation to Board pages and topics.', 'discussion-board-pro' ); ?></p>
		<?php
	} */

	public function boards_meta_fields_render() {
		$options = get_option( 'ctdb_boards_settings' );
		$fields = ctdb_boards_fields();

		foreach ( $fields as $field ) {
			$checked = '';
			if( ! empty( $options['boards_fields'] ) && in_array( $field['id'], $options['boards_fields'] ) ) {
				$checked = 'checked';
			}
			?>
			<input type='checkbox' name='ctdb_boards_settings[boards_fields][<?php echo $field['id']; ?>]' <?php echo $checked; ?> value='<?php echo $field['id']; ?>'><label><?php echo $field['label']; ?></label><br>
		<?php } ?>
		<p class="description"><?php _e( 'Select which meta fields to display for boards on summary page.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function boards_meta_fields_archive_render() {
		$options = get_option( 'ctdb_boards_settings' );
		$fields = ctdb_boards_fields_archive();

		foreach ( $fields as $field ) {
			$checked = '';
			if( ! empty( $options['boards_meta_fields_archive'] ) && in_array( $field['id'], $options['boards_meta_fields_archive'] ) ) {
				$checked = 'checked';
			}
			?>
			<input type='checkbox' name='ctdb_boards_settings[boards_meta_fields_archive][<?php echo $field['id']; ?>]' <?php echo $checked; ?> value='<?php echo $field['id']; ?>'><label><?php echo $field['label']; ?></label><br>
		<?php } ?>
		<p class="description"><?php _e( 'Select which meta fields to display for boards on archive pages.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function boards_orderby_render() {
		$options = get_option( 'ctdb_boards_settings' );
		$fields = array(
			'author'		=> __( 'Author', 'discussion-board-pro' ),
			'date'			=> __( 'Date', 'discussion-board-pro' ),
			'freshness'		=> __( 'Freshness', 'discussion-board-pro' ),
			'rand'			=> __( 'Random', 'discussion-board-pro' ),
			'comment_count'	=> __( 'Most commented', 'discussion-board-pro' ),
			'title'			=> __( 'Title', 'discussion-board-pro' )
		); ?>

		<select name='ctdb_boards_settings[boards_orderby]'>
			<?php foreach( $fields as $key=>$value ) { ?>
				<option value="<?php echo $key; ?>" <?php selected( $options['boards_orderby'], $key ); ?>><?php echo $value; ?></option>
			<?php } ?>
		</select>

		<p class="description"><?php _e( 'Select which field to order Board archives by.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function boards_order_render() {
		$options = get_option( 'ctdb_boards_settings' ); ?>

		<select name='ctdb_boards_settings[boards_order]'>
			<option value="ASC" <?php selected( $options['boards_order'], 'ASC' ); ?>>ASC</option>
			<option value="DESC" <?php selected( $options['boards_order'], 'DESC' ); ?>>DESC</option>
		</select>

		<?php
	}

	public function topics_in_boards_render() {
		$options = get_option( 'ctdb_boards_settings' );
		?>
		<input type='number' name='ctdb_boards_settings[topics_in_boards]' min=0 value="<?php echo $options['topics_in_boards']; ?>" />
		<p class="description"><?php _e ( 'Number of topics to display in Board summary.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function new_topic_button_archive_render() {
		$options = get_option( 'ctdb_boards_settings' );
		$views = array( 'top' => 'Top', 'bottom' => 'Bottom', 'hide' => 'Hide' );
		?>
			<select name='ctdb_boards_settings[new_topic_button_archive]'>
				<?php foreach( $views as $key=>$value ) { ?>
					<option value="<?php echo $key; ?>" <?php selected( $options['new_topic_button_archive'], $key ); ?>><?php echo $value; ?></option>
				<?php } ?>
			</select>
		<?php
	}


	public function register_firstname_render() {
		$options = get_option( 'ctdb_registration_settings' );
		$views = array( 'hide' => 'Hide', 'show' => 'Show', 'required' => 'Required' );
		?>
			<select name='ctdb_registration_settings[register_firstname]'>
				<?php foreach( $views as $key=>$value ) { ?>
					<option value="<?php echo $key; ?>" <?php selected( $options['register_firstname'], $key ); ?>><?php echo $value; ?></option>
				<?php } ?>
			</select>
		<?php
	}

	public function register_lastname_render() {
		$options = get_option( 'ctdb_registration_settings' );
		$views = array( 'hide' => 'Hide', 'show' => 'Show', 'required' => 'Required' );
		?>
			<select name='ctdb_registration_settings[register_lastname]'>
				<?php foreach( $views as $key=>$value ) { ?>
					<option value="<?php echo $key; ?>" <?php selected( $options['register_lastname'], $key ); ?>><?php echo $value; ?></option>
				<?php } ?>
			</select>
		<?php
	}

	public function register_url_render() {
		$options = get_option( 'ctdb_registration_settings' );
		$views = array( 'hide' => 'Hide', 'show' => 'Show', 'required' => 'Required' );
		?>
			<select name='ctdb_registration_settings[register_url]'>
				<?php foreach( $views as $key=>$value ) { ?>
					<option value="<?php echo $key; ?>" <?php selected( $options['register_url'], $key ); ?>><?php echo $value; ?></option>
				<?php } ?>
			</select>
		<?php
	}

	public function register_bio_render() {
		$options = get_option( 'ctdb_registration_settings' );
		$views = array( 'hide' => 'Hide', 'show' => 'Show' );
		?>
			<select name='ctdb_registration_settings[register_bio]'>
				<?php foreach( $views as $key=>$value ) { ?>
					<option value="<?php echo $key; ?>" <?php selected( $options['register_bio'], $key ); ?>><?php echo $value; ?></option>
				<?php } ?>
			</select>
		<?php
	}

	public function enable_profiles_render() {
		$options = get_option( 'ctdb_profiles_settings' );
		?>
		<input type='checkbox' name='ctdb_profiles_settings[enable_profiles]' <?php checked( ! empty( $options['enable_profiles'] ), 1 ); ?> value='1'>
		<p class="description"><?php _e( 'Enable user profile pages.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function enable_author_sidebar_render() {
		$options = get_option( 'ctdb_profiles_settings' );
		?>
		<input type='checkbox' name='ctdb_profiles_settings[enable_author_sidebar]' <?php checked( ! empty( $options['enable_author_sidebar'] ), 1 ); ?> value='1'>
		<p class="description"><?php _e( 'Enable a sidebar when using the plugin author template.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function profiles_tabs_render() {
		$options = get_option( 'ctdb_profiles_settings' );
		$pages = array(
			'profile' 	=> __( 'Profile', 'discussion-board-pro' ),
			'posts'		=> __( 'Topics started', 'discussion-board-pro' ),
			'comments'	=> __( 'Replies', 'discussion-board-pro' ),
			'following'	=> __( 'Following', 'discussion-board-pro' )
		);
		foreach ( $pages as $key=>$value ) {
			$checked = '';
			if( ! empty( $options['profiles_tabs'] ) && in_array( $key, $options['profiles_tabs'] ) ) {
				$checked = 'checked';
			}
			?>
			<input type='checkbox' name='ctdb_profiles_settings[profiles_tabs][<?php echo $key; ?>]' <?php echo $checked; ?> value='<?php echo $key; ?>'><label><?php echo $value; ?></label><br>
		<?php } ?>
		<p class="description"><?php _e( 'Select which tabs to display on the profile page.', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function profiles_fields_render() {
		$options = get_option( 'ctdb_profiles_settings' );
		$fields = ctdb_profile_fields();

		foreach ( $fields as $field ) {
			$checked = '';
			if( ! empty( $options['profiles_fields'] ) && in_array( $field['id'], $options['profiles_fields'] ) ) {
				$checked = 'checked';
			}
			?>
			<input type='checkbox' name='ctdb_profiles_settings[profiles_fields][<?php echo $field['id']; ?>]' <?php echo $checked; ?> value='<?php echo $field['id']; ?>'><label><?php echo $field['label']; ?></label><br>
		<?php } ?>
		<p class="description"><?php _e( 'Select which fields to display on the profile tab (if enabled above).', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function redirect_to_profile_page_render() {
		$options = get_option( 'ctdb_profiles_settings' );
		?>
		<input type='checkbox' name='ctdb_profiles_settings[redirect_to_profile_page]' <?php checked( ! empty( $options['redirect_to_profile_page'] ), 1 ); ?> value='1'>
		<p class="description"><?php _e( 'Display link to user profile page in comment form	(replaces URL to user\'s site)', 'discussion-board-pro' ); ?></p>
		<?php
	}

	public function pro_settings_section_callback() {
	//	echo __( '<p>This section description</p>', 'discussion-board-pro' );
	}

	public function categories_settings_section_callback() {
	//	echo __( '<p>This section description</p>', 'discussion-board-pro' );
	}

	public function boards_settings_section_callback() {
		echo '<p>';
		_e( 'Boards allow you to create multiple Discussion Boards. Maybe you want separate boards for announcements, support, chat...', 'discussion-board-pro' );
		echo '</p>';
	}

	public function registration_settings_section_callback() {
		echo '<p>' . __( 'Specify fields to appear on the registration form. Hide, show, or require them.', 'discussion-board-pro' ) . '</p>';
	}

	public function profiles_settings_section_callback() {
		echo '<p>' . __( 'Front end profile pages and feeds.', 'discussion-board-pro' ) . '</p>';
	}

	public function followers_settings_section_callback() {
		echo '<p>' . __( 'Allow users to receive updates on topics they have chosen to follow.', 'discussion-board-pro' ) . '</p>';
	}

	public function filter_tabs( $tabs ) {
		$tabs = array(
			'options'		=>	__( 'General', 'discussion-board-pro' ),
			'design'		=>	__( 'Design', 'discussion-board-pro' ),
			'user'			=>	__( 'User', 'discussion-board-pro' ),
			'pro'			=>	__( 'Pro', 'discussion-board-pro' ),
			'categories'	=>	__( 'Categories', 'discussion-board-pro' ),
			'boards'		=>	__( 'Boards', 'discussion-board-pro' ),
			'registration'	=>	__( 'Registration', 'discussion-board-pro' ),
			'profiles'		=>	__( 'Profiles', 'discussion-board-pro' ),
			'followers'		=>	__( 'Followers', 'discussion-board-pro' )
		);
		return $tabs;

	}

}
